# Clase Menu dietetico
# @author alu0100891447
# @attr [Array] encabezado Contiene el titulo y su porcentaje de ingesta diaria
# @attr [Array] platos Contiene los platos que forman el menu
# @attr [Array] valores Contiene los valores pertenecientes al menu
class Menu
    attr_reader :encabezado, :platos, :valores
    include Comparable

# Establece el orden de los valores segun el V.C.T
# @param [Menu] anOther Objeto a comparar de la clase Menu
def <=>(anOther)
    get_vct <=> anOther.get_vct
end

#Crea una instancia de la clase Menu
# @param [Array] encabezado Contiene el titulo y su porcentaje de ingesta diaria
# @param [Array] platos Contiene los platos que forman el menu
# @param [Array] valores Contiene los valores pertenecientes al menu
def initialize(encabezado, platos, valores)
    @encabezado, @platos, @valores = encabezado, platos, valores
end

# Obtiene el plato en la posicion i
# @param [number] i Posicion del plato a retornar
# @return [string] Plato de la posicion i
def get_plato(i)
    @platos[i-1]
end

# Obtiene el titulo del menu
# @return [string] Retorna el titulo del menu
def get_titulo
    @encabezado[0]
end

# Obtiene el porcentaje de ingesta diaria
# @return [string] Retorna el porcentaje de ingesta diaria
def get_ingesta
    @encabezado[1]
end

# Obtiene el V.C.T del menu
# @return [number] Retorna el V.C.T
def get_vct
    @valores[0]
end

# Obtiene las proteinas del menu
# @return [number] Retorna las proteinas
def get_proteinas
    @valores[1]
end

# Obtiene las grasas del menu
# @return [number] Retorna las grasas
def get_grasas
    @valores[2]
end

# Obtiene los hidratos del menu
# @return [number] Retorna los hidratos
def get_hidratos
    @valores[3]
end

# Funcion para mostrar los datos en forma de cadena
# @return [String] Cadena que contiene la salida formateada
def to_s
    aux=get_titulo+" ("+get_ingesta+")\n"
    i=0
    while i<platos.length
        aux+="- #{@platos[i][0]}, #{@platos[i][1]} unidades, #{@platos[i][2]} g\n"
        i+=1
    end
    aux+="V.C.T | %\t#{get_vct} kcal | #{get_proteinas}% - #{get_grasas}% - #{get_hidratos}%\n"
end

end

#Clase hija de Menu, para organizarlos por grupos de alimentos
# @author alu0100891447
# @attr [String] grupo_alimentos Grupos de alimentos del menu
class GAlimentos < Menu
    attr_accessor :grupo_alimentos

#Crea una instancia de la clase GAlimentos
# @param [Array] encabezado Contiene el titulo y su porcentaje de ingesta diaria
# @param [Array] platos Contiene los platos que forman el menu
# @param [Array] valores Contiene los valores pertenecientes al menu
# @param [Array] grupo_alimentos Contiene los alimentos que conforman el menu
def initialize(encabezado, platos, valores, alimentos)
    super(encabezado, platos, valores)
    @grupo_alimentos =alimentos
end

# Funcion para mostrar los datos en forma de cadena
# @return [String] Cadena que contiene la salida formateada
def to_s
    aux = "#{super.to_s}Grupo : #{@grupo_alimentos}\n"
end

end

#Clase hija de Menu, para organizarlos por grupos de edades
# @author alu0100891447
# @attr [String] grupo_edad Rango de edades
class GEdad < Menu
    attr_accessor :grupo_edad

#Crea una instancia de la clase GEdad
# @param [Array] encabezado Contiene el titulo y su porcentaje de ingesta diaria
# @param [Array] platos Contiene los platos que forman el menu
# @param [Array] valores Contiene los valores pertenecientes al menu
# @param [Array] grupo_edad Contiene el rango de edades al que va dirigido este menu
def initialize(encabezado, platos, valores, edades)
    super(encabezado, platos, valores)
    @grupo_edad =edades
end

# Funcion para mostrar los datos en forma de cadena
# @return [String] Cadena que contiene la salida formateada
def to_s
    aux = "#{super.to_s}Grupo : #{@grupo_edad}\n"
end

end
